@@ -16,8 +16,7 @@ def load_ts_data(filename, ts_column, sep, target):
         print('First loading %s and then setting %s as date time index...' % (filename, ts_column))
         for codex in codes_list:
             try:
-                df = pd.read_csv(filename, index_col=None, sep=sep, encoding=codex)
-                df.index = pd.to_datetime(df.pop(ts_column))
+                df = pd.read_csv(filename,index_col=ts_column, parse_dates=True)
                 break
             except:
                 print('    Encoder %s or Date time type not working for reading this file...' % codex)
@@ -25,14 +24,17 @@ def load_ts_data(filename, ts_column, sep, target):
     else:
         ### If filename is not a string, it must be a dataframe and can be loaded
         dft = copy.deepcopy(filename)
-        try:
-            dft.index = pd.to_datetime(dft.pop(ts_column))
-            preds = [x for x in list(dft) if x not in [target]]
-            df = dft[[target]+preds]
-        except Exception as e:
-            print(e)
-            print('Error: Could not convert Time Series column to an index. Please check your input and try again')
-            return ''
+        if type(dft.index) == pd.DatetimeIndex:
+            return dft
+        else:
+            try:
+                dft.index = pd.to_datetime(dft.pop(ts_column))
+                preds = [x for x in list(dft) if x not in [target]]
+                df = dft[[target]+preds]
+            except Exception as e:
+                print(e)
+                print('Error: Could not convert Time Series column to an index. Please check your input and try again')
+                return ''
     return df
 
 
